==> h-vue3-components-dev-1.0.11.tgz: package/es/src/packages/components/forms/text/Text.vue.js <==
import { inject as f, computed as c, ref as y, resolveComponent as O, openBlock as E, createElementBlock as T, Fragment as I, createVNode as v, mergeProps as D, unref as n, isRef as g, toHandlers as B, withCtx as M, createTextVNode as F, toDisplayString as J } from "vue";
import i from "../../../utils/formUtil.js";
import j from "../../i18n/I18nDialog.vue.js";
import k from "../../../store/index.js";
import { getPlaceholder as C, getSuffix as U } from "../../../utils/i18nUtil.js";
const $ = {
  __name: "Text",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: Object,
    modelValue: String | Number,
    isTableSearch: {
      type: Boolean,
      default: !1
    },
    isEdit: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["update:modelValue"],
  setup(b, { emit: V }) {
    const p = f("formData"), m = f("changeFieldData"), d = c(() => i.isEmpty(e.option.readOnly) ? !1 : e.option.readOnly), e = b, h = V, u = y(""), l = c({
      get: () => {
        let t = e.modelValue;
        if (e.option.isI18n)
          try {
            e.isEdit ? u.value = JSON.parse(t) : u.value = JSON.parse(
              p.value[e.option.fieldName + "_I18n"]
            );
          } catch {
            u.value = "", l.value = t;
          }
        else
          l.value = t;
        return t;
      },
      set: (t) => {
        h("update:modelValue", t);
      }
    }), w = () => {
      let t = l.value, o = e.option.dataType;
      o === "money(yuan)" ? t = i.formatMoney(t) : o === "money(qian)" ? t = i.formatMoney(Number(t) / 1e3, 2) : o === "money(wan)" && (t = i.formatMoney(Number(t) / 1e4, 2)), l.value = t;
    }, N = (t) => {
      let o = e.option.dataType;
      (o === "money(yuan)" || o === "money(qian)" || o === "money(wan)" || o === "money(baiwan)" || o === "money(yi)") && (l.value = i.toMoney(t));
    };
    function x(t) {
      m && m(e.option.fieldName, t);
    }
    const r = y(!1);
    function S() {
      e.option.isI18n && !e.isTableSearch && (r.value = !0, d.value = !0);
    }
    function _(t) {
      let o = {}, s = "";
      t.forEach((a) => {
        o[a.lang] = a.content, a.lang == k.getters.i18n && (s = a.content);
      }), e.isEdit ? l.value = JSON.stringify(o) : (l.value = s, p.value[e.option.fieldName + "_I18n"] = JSON.stringify(o)), r.value = !1;
    }
    return (t, o) => {
      const s = O("el-input");
      return E(), T(I, null, [
        v(s, D({
          ref: "input",
          type: "text",
          modelValue: n(l),
          "onUpdate:modelValue": o[0] || (o[0] = (a) => g(l) ? l.value = a : null),
          placeholder: n(C)(e.option)
        }, B(e.event), {
          onKeyup: N,
          onBlur: w,
          onClick: S,
          maxlength: e.option.maxlength,
          "show-word-limit": n(i).isEmpty(e.option["show-word-limit"]) ? !1 : e.option["show-word-limit"],
          disabled: n(i).isEmpty(e.option.disabled) ? !1 : e.option.disabled,
          readonly: n(d),
          clearable: !0,
          autocomplete: "off",
          onInput: x
        }), {
          suffix: M(() => [
            F(J(n(U)(e.option)), 1)
          ]),
          _: 1
        }, 16, ["modelValue", "placeholder", "maxlength", "show-word-limit", "disabled", "readonly"]),
        v(j, {
          modelValue: n(r),
          "onUpdate:modelValue": o[1] || (o[1] = (a) => g(r) ? r.value = a : null),
          title: e.option.label,
          entitle: e.option.enlabel,
          data: n(u),
          onSubmit: _
        }, null, 8, ["modelValue", "title", "entitle", "data"])
      ], 64);
    };
  }
};
export {
  $ as default
};

==> h-vue3-components-dev-1.0.31.tgz: package/es/src/packages/components/forms/text/Text.vue.js <==
import "../../../../../node_modules/element-plus/theme-chalk/base.css.js";
import "../../../../../node_modules/element-plus/theme-chalk/el-input.css.js";
import { inject as f, computed as c, ref as y, openBlock as E, createElementBlock as O, Fragment as I, createVNode as v, mergeProps as T, unref as n, isRef as g, toHandlers as D, withCtx as B, createTextVNode as M, toDisplayString as F } from "vue";
import i from "../../../utils/formUtil.js";
import J from "../../i18n/I18nDialog.vue.js";
import j from "../../../store/index.js";
import { getPlaceholder as k, getSuffix as U } from "../../../utils/i18nUtil.js";
import { ElInput as q } from "../../../../../node_modules/element-plus/es/components/input/index.js";
const G = {
  __name: "Text",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: Object,
    modelValue: String | Number,
    isTableSearch: {
      type: Boolean,
      default: !1
    },
    isEdit: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["update:modelValue"],
  setup(b, { emit: V }) {
    const p = f("formData"), s = f("changeFieldData"), d = c(() => i.isEmpty(e.option.readOnly) ? !1 : e.option.readOnly), e = b, h = V, u = y(""), l = c({
      get: () => {
        let t = e.modelValue;
        if (e.option.isI18n)
          try {
            e.isEdit ? u.value = JSON.parse(t) : u.value = JSON.parse(
              p.value[e.option.fieldName + "_I18n"]
            );
          } catch {
            u.value = "", l.value = t;
          }
        else
          l.value = t;
        return t;
      },
      set: (t) => {
        h("update:modelValue", t);
      }
    }), w = () => {
      let t = l.value, o = e.option.dataType;
      o === "money(yuan)" ? t = i.formatMoney(t) : o === "money(qian)" ? t = i.formatMoney(Number(t) / 1e3, 2) : o === "money(wan)" && (t = i.formatMoney(Number(t) / 1e4, 2)), l.value = t;
    }, N = (t) => {
      let o = e.option.dataType;
      (o === "money(yuan)" || o === "money(qian)" || o === "money(wan)" || o === "money(baiwan)" || o === "money(yi)") && (l.value = i.toMoney(t));
    };
    function x(t) {
      s && s(e.option.fieldName, t);
    }
    const r = y(!1);
    function S() {
      e.option.isI18n && !e.isTableSearch && (r.value = !0, d.value = !0);
    }
    function _(t) {
      let o = {}, m = "";
      t.forEach((a) => {
        o[a.lang] = a.content, a.lang == j.getters.i18n && (m = a.content);
      }), e.isEdit ? l.value = JSON.stringify(o) : (l.value = m, p.value[e.option.fieldName + "_I18n"] = JSON.stringify(o)), r.value = !1;
    }
    return (t, o) => {
      const m = q;
      return E(), O(I, null, [
        v(m, T({
          ref: "input",
          type: "text",
          modelValue: n(l),
          "onUpdate:modelValue": o[0] || (o[0] = (a) => g(l) ? l.value = a : null),
          placeholder: n(k)(e.option)
        }, D(e.event), {
          onKeyup: N,
          onBlur: w,
          onClick: S,
          maxlength: e.option.maxlength,
          "show-word-limit": n(i).isEmpty(e.option["show-word-limit"]) ? !1 : e.option["show-word-limit"],
          disabled: n(i).isEmpty(e.option.disabled) ? !1 : e.option.disabled,
          readonly: n(d),
          clearable: !0,
          autocomplete: "off",
          onInput: x
        }), {
          suffix: B(() => [
            M(F(n(U)(e.option)), 1)
          ]),
          _: 1
        }, 16, ["modelValue", "placeholder", "maxlength", "show-word-limit", "disabled", "readonly"]),
        v(J, {
          modelValue: n(r),
          "onUpdate:modelValue": o[1] || (o[1] = (a) => g(r) ? r.value = a : null),
          title: e.option.label,
          entitle: e.option.enlabel,
          data: n(u),
          onSubmit: _
        }, null, 8, ["modelValue", "title", "entitle", "data"])
      ], 64);
    };
  }
};
export {
  G as default
};
